@@ -1,5 +1,9 @@
+#![forbid(unsafe_code)]
+
 pub use bincode;
-pub use esvc_traits::{anyhow, Engine, EngineError};
+
+#[doc(no_inline)]
+pub use esvc_traits::Engine;
 
 mod hash;
 pub use hash::*;
@@ -7,5 +11,8 @@ pub use hash::*;
 mod graph;
 pub use graph::*;
 
+mod dot;
+pub use dot::*;
+
 mod workcache;
 pub use workcache::*;
